.TH "RNABOB" 1 "Dec 2012" "RNABOB 2.2.1" rnabob

.SH NAME
.B rnabob
- search for RNA motifs in sequence databases
.SH SYNOPSIS
.B rnabob [options] descriptor-file seqfile
.SH DESCRIPTION
.B rnabob
allows searching a sequence database for RNA structural motifs.
The probe motif is specified in the 
.B descriptor-file
which describes
its primary sequence, secondary structure, and tertiary constraints.
The sequence file to search is specified by 
.B seqfile.

.B seqfile
must contain DNA or RNA sequence. Format is flexible; most common
formats are accepted, including FASTA, GCG, GenBank, and EMBL database
formats. IUPAC degenerate nucleotide codes are allowed.

The descriptor file syntax is fairly powerful, and allows a great deal
of freedom for specifying RNA motifs. The syntax is therefore a bit
complicated. Example descriptor files 
.B r17.des,
.B pseudoknot.des,
and
.B trna.des
are provided with the rnabob source distribution.

The descriptor file has two parts: a "topology" description and an
"explicit" description. 

The first non-blank, non-comment line of the file is the topology
description. It defines the order of occurrence of a series of
single-stranded, double-stranded, and related elements. Each element
must be given a unique name (a number, typically) and must be prefixed
with 's', 'h', or 'r', indicating single-strand, helical, or a
relational element. Helical and relational elements are paired to
other elements, which are suffixed by a prime, '.

For example:

.B h1 s1 h1'

describes a hairpin loop structure with a simple helix and
single-stranded loop. If the helix always contained a non-canonical
base pair at one position, the topology could be described as:

.B h1 r1 h2 s1 h2' r1' h1'

where r1, r1' indicate a correlation, where the sequence of r1
constrains the sequence of r1'. (Helices are a special case of this.)

The remaining non-comment, non-blank lines are explicit descriptions
of each element in turn. Each line contains 3 or 4 fields, separated
by tabs or blank space. The first field is the name of the element,
from the topology description. The second field is the number of
mismatches allowed in this element. The third field is the primary
sequence constraint to apply to this element.

Helices and relational element pairs are specified on a single line
rather than two.  Mismatches and primary sequence constraints are
given as pairs, separated by a colon ``:''. The left side is the
constraint applied to the upstream element, and the right side is
applied to the downstream elements.

The primary sequence constraint is given as a sequence of nucleotides.
Any IUPAC single-letter code is recognized, including N if the
position can have any base identity. Allowed length variations are
specified with asterisks {\tt *}, where each {\tt *} will allow either 0 or 1
N at that position. For example,

.B GGAGG******NNNAUG

specifies a GGAGG Shine/Dalgarno site and an AUG initiation codon,
separated by a spacer of 3 to 9 nucleotides of any sequence.

An alternative syntax can be used for very long gaps. 
.B GGAGG[10]NNNAUG
is the same as 
.B GGAGG**********NNNAUG.

Be careful defining variable length helices and relational elements;
if the number and type (gap or identity) of position do not match on
left and right sides, the program will refuse to accept the descriptor.

Relational elements have an additional field which specifies a
``transformation matrix'' of four nucleotides, specifying the rule for
making the r' pattern from the r sequence in order A-C-G-T. For
example, the transformation matrix for a simple helix is TGCA; if you
allow G-U pairs, it is TGYR. RNABOB allows G-U pairing by default and
uses the TGYR matrix for helical elements.

For example, the explicit description of our hairpin might be:

.B h1 0:0 NNN:NNN

.B r1 0:0 R:N  GNAN

.B h2 0:0 **NC:GN**

.B s1 0 UUCG

This describes a a stem of 6 to 8 base pairs, in which the 4th pair from
the bottom of the stem must be a non-canonical GA pair. Note that, in
general, the left side of the primary constraint for helices and
relational elements is redundant, and should be given as all N. In
some cases it is convenient to constrain the right side to require a
particular base pair (GU, for instance) at one position.

A note on mismatches: The split format for helices and relational
elements works like this. The number on the left constrains the
primary sequence match of the left side of the primary constraint. The
number on the right contrains the match of the right side of the
primary constraint, {\em after} that side has been constructed
according to the sequence on the left. In other words, the number on
the left constrains the mismatches in primary sequence only, while the
number on the right will constrain the number of mispaired positions
in the helix.

Finally: any line that begins with a pound sign "#" is a comment
line, and will not be interpreted by the pattern compiler.

.SH OPTIONS
.TP
.B -c 
Complement: search for the pattern on the complementary
strands too.
.TP
.B -h 
Help: print out some brief usage and version info for the program.
.TP
.B -q
Quiet: suppress the verbose header on the output. Useful for
directly piping rnabob output into another program or filter.
.TP
.B -s 
Skip: a hack to avoid a problem in GenBank/EMBL. There
are some sequences in the database which have long stretches of
ambiguous sequence (N's). Descriptors with no primary sequence
constraints will match these garbage sequences at many, many
positions, and generate huge outputs (sometimes enough to crash the
program and shaman). SKIPMULT toggles a search strategy that skips
forward a pattern-length rather than a single base when a match is
found, thus printing out only a single match when overlapping
matches are found.
.TP
.B -F
Fancier output: print out the sequence that matched. Still pretty
rudimentary.

.SH REFERENCES
Gautheret D., Major F., and Cedergren R. Pattern searching/alignment
with RNA primary and secondary structures: an effective descriptor for
tRNA. CABIOS  6:325--331, 1990.
.PP
Eddy S.R. RNABOB: a program to search for RNA secondary structure
motifs in sequence databases. Unpublished.
.SH SEE ALSO
The rnabob User's Guide, 
.B rnabob.ps.

.SH NOTES

This software and documentation is Copyright (C) 1992-2012, Sean
R. Eddy.  It is freely distributable under terms of the GNU General
Public License. See COPYING in the source code distribution for more
details.

.nf
Sean Eddy
HHMI Janelia Farm Research Campus
http://selab.janelia.org
.fi
